import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';

class RemoteImage extends StatelessWidget {
  final String imagePath;
  final double? width;
  final double? height;
  final bool fillHeight;
  final BoxFit fit;
  final String errMsg;

  const RemoteImage({
    Key? key,
    required this.imagePath,
    this.width,
    this.height,
    this.fillHeight = false,
    this.fit = BoxFit.cover,
    this.errMsg = "Image failed to load",
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      color: Colors.grey.shade200,
      height: fillHeight ? double.infinity : null,
      child: CachedNetworkImage(
        imageUrl: imagePath,
        width: width ?? double.infinity,
        height: height,
        fit: fit,
        errorWidget: (context, url, error) => Container(
          color: Colors.white,
          width: double.infinity,
          height: height,
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              const Icon(
                Icons.warning,
                size: 40,
                color: Colors.red,
              ),
              Text(
                widget.errMsg,
                textAlign: TextAlign.center,
                style: TextStyle(
                  fontSize: 11,
                  color: Colors.black.withOpacity(0.4),
                ),
              )
            ],
          ),
        ),
      ),
    );
  }
}
